/*
 * Title:        bits/data_t.hpp
 * Description:  C++ header-only wrapper for C-ABI data_t type
 * $Copyright (c) 2015-2017, 2019, 2022-2023 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA, and/or its subsidiaries and/or its affiliates and/or their licensors.$
 * Use, reproduction, transfer, publication or disclosure is prohibited except as specifically provided for in your License Agreement with Software AG
 */

/* This file contains free functions for data_t operators
 */

#include <data_t.hpp>
#include <functions.hpp>
#include <visitors.hpp>

/** Returns true if the lhs data_t is a string and the string inside matches the const char* supplied */
bool operator==(const data_t& lhs, const char*& rhs) {
	switch (lhs.type_tag()) {
		case SAG_DATA_EMPTY:
			return rhs == nullptr;
		case SAG_DATA_STRING:
		case SAG_DATA_CONST_STRING:
			return rhs && strcmp(get<const char*>(lhs), rhs) == 0;
		default:
			return false;
	}	
}

/** Returns true if the lhs data_t is an integer and the value matches the integer supplied */
bool operator==(const data_t& lhs, const int& rhs) {
	return lhs.type_tag() == SAG_DATA_INTEGER && get<int>(lhs) == rhs;
}

/** Returns true if the lhs data_t is an double and the value matches the double supplied */
bool operator==(const data_t& lhs, const double& rhs) {
	return lhs.type_tag() == SAG_DATA_DOUBLE && get<double>(lhs) == rhs;
}

// operator== free functions with data_t on the right
template <typename T>
bool operator==(const T& lhs, const data_t& rhs) {
	return operator==(rhs, lhs); // Sides swapped over
}
template operator==<const char*>;
template operator==<int>;
template operator==<double>;

// operator!= free functions
template <typename L, typename R>
bool operator!=(const L& lhs, const R& rhs) {
	return !operator==(lhs, rhs);
}
template operator!=<data_t, const char*>;
template operator!=<const char*, data_t>;
template operator!=<data_t, int>;
template operator!=<int, data_t>;
template operator!=<data_t, double>;
template operator!=<double, data_t>;
