/*
 * client_status_names.hpp
 *
 * $Copyright (c) 2018, 2020 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA, and/or its subsidiaries and/or its affiliates and/or their licensors.$
 * Use, reproduction, transfer, publication or disclosure is prohibited except as specifically provided for in your License Agreement with Software AG
 */

/** @file
 *
 * Contains the key names for all standard status values within the correlator.
 */

#ifndef APAMA_CLIENT_STATUS_NAMES
#define APAMA_CLIENT_STATUS_NAMES

namespace com {
namespace apama {

/** Contains the key names for all standard status values within the correlator. */
namespace client_status {

/** Uptime in ms */
static char const * const UPTIME_SECONDS = "uptime";
/** Number of consumers attached to the correlator */
static char const * const CONSUMERS_TOTAL = "numConsumers";
/** Number of contexts in the correlator */
static char const * const CONTEXTS_TOTAL = "numContexts";
/** Number of events emitted from correlator */
static char const * const CREATED_OUTPUT_TOTAL = "numEmits";
/** Number of event types defined */
static char const * const EVENT_TYPES_TOTAL = "numEventTypes";
/** Number of events fast tracked */
static char const * const ROUTE_TOTAL = "numFastTracked";
/** Total number of events on input contexts' queues */
static char const * const QUEUED_INPUT_PUBLIC_TOTAL = "numInputQueuedInput";
/** Number of java applications */
static char const * const JAVA_APPLICATIONS_TOTAL = "numJavaApplications";
/** Number of active listeners */
static char const * const LISTENERS_TOTAL = "numListeners";
/** Number of monitors */
static char const * const MONITORS_TOTAL = "numMonitors";
/** Number of events on the output queue */
static char const * const QUEUED_OUTPUT_TOTAL = "numOutEventsQueued";
/** Number of events sent */
static char const * const OUTPUT_TOTAL = "numOutEventsSent";
/** Number of events that have been emitted but not yet acknowledge */
static char const * const OUTPUT_UNACKED_TOTAL = "numOutEventsUnAcked";
/** Number of events taken of output queue */
static char const * const PROCESSED_TOTAL = "numProcessed";
/** Number of monitor processes */
static char const * const MONITOR_INSTANCES_TOTAL = "numProcesses";
/** Number of events on the fast track queue */
static char const * const QUEUED_ROUTE_TOTAL = "numQueuedFastTrack";
/** Number of events on the input queue */
static char const * const QUEUED_INPUT_TOTAL = "numQueuedInput";
/** Number of events received (includes those that failed to be parsed) */
static char const * const INPUT_TOTAL = "numReceived";
/** Number of snapshots since startup */
static char const * const PERSISTENCE_SNAPSHOTS_TOTAL = "persistenceNumSnapshots";
/** The clock time of the last complete snapshot */
static char const * const PERSISTENCE_LAST_SNAPSHOT_TIMESTAMP = "persistenceLastSnapshotTime";
/** The EWMA of time taken to wait for a snapshot, in milliseconds */
static char const * const PERSISTENCE_SNAPSHOT_WAIT_EWMA_SECONDS = "persistenceSnapshotWaitTimeEwmaMillis";
/** The EWMA of time taken to commit, in milliseconds */
static char const * const PERSISTENCE_COMMIT_TIME_EWMA_SECONDS = "persistenceCommitTimeEwmaMillis";
/** The EWMA of number of rows changed */
static char const * const PERSISTENCE_SNAPSHOT_ROWS_CHANGED_EWMA_TOTAL = "persistenceLastSnapshotRowsChangedEwma";
/** Number of active sub-listeners */
static char const * const SUB_LISTENERS_TOTAL = "numSubListeners";
/** Name of the slowest receiver */
static char const * const SLOWEST_OUTPUT_QUEUE_NAME = "slowestReceiver";
/** Number of events waiting on that receiver's queue */
static char const * const SLOWEST_OUTPUT_QUEUE_SIZE_TOTAL = "slowestReceiverQueueSize";
/** Latency enqueued at that context */
static char const * const SLOWEST_INPUT_QUEUE_LATENCY_SECONDS = "mostBackedUpICLatency";
/** Number of executors waiting on that context's queue */
static char const * const SLOWEST_INPUT_QUEUE_SIZE_TOTAL = "mostBackedUpICQueueSize";
/** Name of the most backlogged input context */
static char const * const SLOWEST_INPUT_QUEUE_CONTEXT_NAME = "mostBackedUpInputContext";
/** Number of events on the enqueue queue */
static char const * const ENQUEUE_QUEUE_SIZE = "enqueueQueueSize";
/** VM usage in MB */
static char const * const VIRTUAL_MEMORY_SIZE_MB = "virtualMemoryMB";
/** PM usage in MB */
static char const * const PHYSICAL_MEMORY_SIZE_MB = "physicalMemoryMB";
/** Peak PM usage in MB */
static char const * const PEAK_PHYSICAL_MEMORY_SIZE_MB = "peakPhysicalMemoryMB";
/** Number of pages per second that are being read from swap space */
static char const * const SWAP_PAGES_READ_HERTZ = "swapPagesRead";
/** Number of pages per seconds that are being written to swap space */
static char const * const SWAP_PAGES_WRITE_HERTZ = "swapPagesWrite";
/** JVM using heap memory in bytes */
static char const * const JVM_HEAP_USED_MB = "jvmMemoryHeapUsedMB";
/** JVM free heap memory in bytes */
static char const * const JVM_HEAP_FREE_MB = "jvmMemoryHeapFreeMB";
/** JVM using non-heap memory in bytes */
static char const * const JVM_NON_HEAP_USED_MB = "jvmMemoryNonHeapUsedMB";
/** JVM using buffer pool in bytes */
static char const * const JVM_BUFFER_POOL_USED_MB = "jvmMemoryBufferPoolUsedMB";
/** JVM total memory used in bytes, jvmUsedHeap+jvmUsedNonHeap+jvmUsedBufferPool */
static char const * const JVM_MEMORY_ALL_MB = "jvmMemoryAllUsedMB";
/** JVM number of threads */
static char const * const JVM_NUM_THREADS = "jvmNumThreads";

}}}

#endif
