/*
 * Title:        sag_internal/logging.hpp
 * Description:  Internal logging implementation code
 * $Copyright (c) 2015-2017, 2020, 2022 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA, and/or its subsidiaries and/or its affiliates and/or their licensors.$
 * Use, reproduction, transfer, publication or disclosure is prohibited except as specifically provided for in your License Agreement with Software AG
 */


#ifndef _SAG_INTERNAL_LOGGING_HPP_
#define _SAG_INTERNAL_LOGGING_HPP_

namespace com {
namespace softwareag {
namespace _DATAT_INTERNAL_CPP_NAMESPACE { 

template<Logger::level_t LEVEL, typename... ARGS>
inline void Logger::log(const char *format, ARGS... args) const
{
	if (isEnabled(LEVEL)) {
		sag_log_at(category.c_str(), LEVEL, ("<%s> "+std::string(format)).c_str(), prefix.c_str(), args...);
	}
}

template<typename... ARGS>
inline void Logger::log(Logger::level_t LEVEL, const char *format, ARGS... args) const
{
	if (isEnabled(LEVEL)) {
		sag_log_at(category.c_str(), LEVEL, ("<%s> "+std::string(format)).c_str(), prefix.c_str(), args...);
	}
}


template<Logger::level_t LEVEL, typename... ARGS>
inline void Logger::log(const std::string &format, ARGS... args) const
{
	if (isEnabled(LEVEL)) {
		sag_log_at(category.c_str(), LEVEL, ("<%s> "+format).c_str(), prefix.c_str(), args...);
	}
}

template<typename... ARGS>
inline void Logger::log(Logger::level_t LEVEL, const std::string &format, ARGS... args) const
{
	if (isEnabled(LEVEL)) {
		sag_log_at(category.c_str(), LEVEL, ("<%s> "+format).c_str(), prefix.c_str(), args...);
	}
}

inline Logger::level_t Logger::getLevelImpl() const
{
	return sag_get_log_level(category.c_str());
}

inline CacheOwner::CacheOwner()
	: cache(sag_create_thread_cache()), inuse(false)
{
}

inline CacheOwner::~CacheOwner()
{
	assert(!inuse);
	sag_destroy_thread_cache(cache);
}

inline CacheForThisThread::CacheForThisThread(CacheOwner &owner)
	: owner(owner)
{
	assert(!owner.inuse);
	owner.inuse = true;
	sag_set_thread_cache(owner.cache);

}
inline CacheForThisThread::~CacheForThisThread()
{
	assert(owner.inuse);
	sag_set_thread_cache(NULL);
	owner.inuse = false;
}

}}} // com.softwareag.connectivity

#endif // _SAG_INTERNAL_LOGGING_HPP_
