/*
 * Title:        sag_internal/remote_plugins.hpp
 * Description:  Implementation of RemoteHostSide and RemoteTransportSide
 * $Copyright (c) 2015-2017, 2020, 2022 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA, and/or its subsidiaries and/or its affiliates and/or their licensors.$
 * Use, reproduction, transfer, publication or disclosure is prohibited except as specifically provided for in your License Agreement with Software AG
 */


#ifndef _SAG_INTERNAL_REMOTE_PLUGINS_HPP_
#define _SAG_INTERNAL_REMOTE_PLUGINS_HPP_

/**
 * @file C++ shim classes used by plugin libraries to call C exported free functions on apclient that expose correlator 
 functionality. The function signatures are in c_functions.hpp and the actual implementations in apclient are in 
 cpp-common/general-util/src/CConnectivity.cpp
*/

namespace com {
namespace softwareag {
namespace _DATAT_INTERNAL_CPP_NAMESPACE { 


/** @internal
 */
inline void RemoteHostSide::sendBatchTowardsHost(Message *start, Message *end)
{
	sag_error_t result = fn(other, reinterpret_cast<sag_underlying_message_t*>(start), reinterpret_cast<sag_underlying_message_t*>(end));
	(void) result; // don't want other plugins to affect us, so suppress errors
}

/** @internal
 */
inline void RemoteTransportSide::sendBatchTowardsTransport(Message *start, Message *end)
{
	sag_error_t result = fn(other, reinterpret_cast<sag_underlying_message_t*>(start), reinterpret_cast<sag_underlying_message_t*>(end));
	(void) result; // don't want other plugins to affect us, so suppress errors
}

}}} // com.softwareag.connectivity

#endif // _SAG_INTERNAL_REMOTE_PLUGINS_HPP_
